==> cms-db_v0.6.1.tar.gz: admin/index.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

include('checkphp.inc.php');

if (!isset($_GET['locale']) or $_GET['locale'] == '') {
	if(file_exists('../data/settings/locale.inc.php')) {
		include('../data/settings/locale.inc.php');
		$langcode = $locale_default;
	} else {
		$langcode = 'de';
	}
} else {
	$langcode = $_GET['locale'];
}

include('locale.inc.php');
$locale = new LocalizingClass('index', $langcode);

$special = $_GET['special'];

$message = locale('text_normal',true);
$background = '#ddd';
$line = '#eee';
$pleaselogin = true;

if ($special == 'wrongpw') {
	$message = locale('text_wrongpw',true);
	$background = '#f60';
	$line = '#ffe500';
	$pleaselogin = false;
} elseif ($special == 'logout') {
	$message = locale('text_logout',true);
	$background = '#ddf';
	$pleaselogin = false;
} elseif ($special == 'firstrun') {
	$message = locale('text_firstrun',true);
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title>cms -db</title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<style type="text/css">
		/*<![CDATA[*/
		body, html {
			height: 100%;
		}
		body {
			font-family: "Bitstream Vera Sans", Arial, Helvetica, sans-serif;
			font-size: 1.0em;
			margin: 0;
			padding: 0;
			background-color: <?php echo $background; ?>;
		}
		#horizon {
			background-color: <?php echo $background; ?>;
			text-align: center;
			position: absolute;
			top: 50%;
			left: 0;
			width: 100%;
			height: 1px;
			overflow: visible;
			visibility: visible;
			display: block;
		}
		#left {
			background-color: <?php echo $background; ?>;
			text-align: right;
			width: 49%;
			height: 11em;
			position: absolute;
			left: 0;
			top: -5.5em;
		}
		#left h1 {
			margin: 0;
			font-size: 4.5em;
			font-family: "Bitstream Vera Sans", Arial, Helvetica sans-serif;
			font-weight: normal;
			color: #032b4f;
		}
		#left p {
			margin: 0;
		}
		#right {
			background-color: <?php echo $background; ?>;
			width: 49%;
			text-align: left;
			height: 15em;
			position: absolute;
			left: 50%;
			top: -7.5em;
		}
		#right form {
			border-left: 3px solid <?php echo $line; ?>;
			padding: 5em 0 0 10px;
			height: 10em;
		}
		#right form input {
			margin: 0 0 0.3em 0;
		}
		a:link, a:active, a:visited {
			color: #0000ff;
			text-decoration: none;
		}
		a:hover {
			color: #0000ff;
			text-decoration: underline;
		}
		#user, #pass {
			width: 13em;
		}
		/*]]>*/
		</style>
	</head>
	<body>

		<form action="index.php" method="GET" style="position: absolute; top: 0px; right: 0px; padding: .2em">
			<select name="locale" size="1" onchange="document.forms[0].submit()">
				<?php
				if ($handle = opendir('./locales')) {
					while (false !== ($file = readdir($handle))) {
						if(is_file('./locales/'.$file.'/info.php')) {
							include('./locales/'.$file.'/info.php');
							if ($file == $langcode) {
								echo '<option value="'.$file.'" selected="selected">'.$locale_info["name"].'</option>';
							} else {
								echo '<option value="'.$file.'">'.$locale_info["name"].'</option>';
							}
						}
					}
					closedir($handle);
				}
				?>
			</select>
			<input type="submit" value="OK" />
		</form>

		<div id="horizon">
			<div id="left">
				<h1>cms -db</h1>
				<?php if ($pleaselogin == true) { locale('text_pleaselogin'); } ?>
				<p>&nbsp;</p>
				<p><?php echo $message; ?></p>
			</div>
			<div id="right">
				<form action="login.php" method="POST">
					<input type="hidden" name="locale" value="<?php echo $langcode ?>" />
					<input type="text" name="user" id="user" value="" /> <label for="user"><?php locale('label_username') ?></label><br />
					<input type="password" name="pass" id="pass" value="" /> <label for="pass"><?php locale('label_password') ?></label><br />
					<input type="submit" value="<?php locale('button_login') ?>" /><br />
				</form>
			</div>
		</div>
		
		<?php
		$version = trim(file_get_contents('./update/version.txt'));
		if (file_exists('../data/version.txt')) {
			$version_installed = trim(file_get_contents('../data/version.txt'));
			if ($version != $version_installed) {
				$version = $version.' [ ! '.$version_installed.' ]';
			}
		}
		?>
		<div style="position: absolute; left: 0px; bottom: 0px; padding: .2em">
			<a href="version.php" style="font-size: .8em; color: #99aec2; text-decoration: none"><?php echo $version ?></a>
		</div>

	</body>
</html>

==> cms-db_v0.7.5.tar.gz: admin/index.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

include('checkphp.inc.php');

if (!isset($_GET['locale']) or $_GET['locale'] == '') {
	if(file_exists('../data/settings/locale.inc.php')) {
		include('../data/settings/locale.inc.php');
		$langcode = $locale_default;
	} else {
		$langcode = 'de';
	}
} else {
	$langcode = $_GET['locale'];
}

include('locale.inc.php');
$locale = new LocalizingClass('index', $langcode);

$special = $_GET['special'];

$message = locale('text_normal',true);
$background = '#ddd';
$line = '#eee';
$pleaselogin = true;

if ($special == 'wrongpw') {
	$message = locale('text_wrongpw',true);
	$background = '#f60';
	$line = '#ffe500';
	$pleaselogin = false;
} elseif ($special == 'logout') {
	$message = locale('text_logout',true);
	$background = '#ddf';
	$pleaselogin = false;
} elseif ($special == 'firstrun') {
	$message = locale('text_firstrun',true);
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title>cms -db</title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<?php
include('mobile.inc.php');
if (!mobile()) {
?>
		<style type="text/css">
		/*<![CDATA[*/
		body, html {
			height: 100%;
		}
		body {
			font-family: "Bitstream Vera Sans", Arial, Helvetica, sans-serif;
			font-size: 1.0em;
			margin: 0;
			padding: 0;
			background-color: <?php echo $background; ?>;
		}
		#horizon {
			background-color: <?php echo $background; ?>;
			text-align: center;
			position: absolute;
			top: 50%;
			left: 0;
			width: 100%;
			height: 1px;
			overflow: visible;
			visibility: visible;
			display: block;
		}
		#left {
			background-color: <?php echo $background; ?>;
			text-align: right;
			width: 49%;
			height: 11em;
			position: absolute;
			left: 0;
			top: -5.5em;
		}
		#left h1 {
			margin: 0;
			font-size: 4.5em;
			font-family: "Bitstream Vera Sans", Arial, Helvetica sans-serif;
			font-weight: normal;
			color: #032b4f;
		}
		#left p {
			margin: 0;
		}
		#right {
			background-color: <?php echo $background; ?>;
			width: 49%;
			text-align: left;
			height: 15em;
			position: absolute;
			left: 50%;
			top: -7.5em;
		}
		#version {
			position: absolute;
			left: 0px;
			bottom: 0px;
			padding: .2em;
		}
		#right form {
			border-left: 3px solid <?php echo $line; ?>;
			padding: 5em 0 0 10px;
			height: 10em;
		}
		#right form input {
			margin: 0 0 0.3em 0;
		}
		a:link, a:active, a:visited {
			color: #0000ff;
			text-decoration: none;
		}
		a:hover {
			color: #0000ff;
			text-decoration: underline;
		}
		#user, #pass {
			width: 13em;
		}
		#loading {
			display: none;
			position: fixed;
			top: 0;
			left: 0;
			right: 0;
			bottom: 0;
			background: #fff;
			color: #000;
			padding: 1em;
		}
		#loading span {
			font-weight: normal;
			font-size: 1.5em;
		}
		#loading div {
			position: fixed;
			bottom: 0;
			right: 0;
			left: 0;
			font-size: 100pt;
			color: #eee;
			font-weight: normal;
			text-align: left;
			font-family: "Bitstream Vera Sans", Arial, Helvetica, sans-serif;
		}
		/*]]>*/
		</style>
<?php
} else {
?>
		<style type="text/css">
		/*<![CDATA[*/
		body, html {
			min-height: 100%;
			font-weight: sans-serif;
		}
		body {
			background-color: <?php echo $background; ?>;
		}
		#loading {
			display: none;
		}
		h1 {
			margin: 0;
			font-size: 2em;
			font-weight: bold;
			margin-top: 1.5em;
			color: #032b4f;
		}
		p + p {
			margin: 0;
		}
		#right form {
			margin-top: 1em;
		}
		#user, #pass {
			width: 4em;
		}
		a:link, a:active, a:visited {
			color: #0000ff;
			text-decoration: none;
		}
		a:hover {
			color: #0000ff;
			text-decoration: underline;
		}
		/*]]>*/
		</style>
		<meta name="viewport" content="width = device-width, height = device-height, initial-scale = 1.0" />
<?php
}
?>
		<style type="text/css">
		/*<![CDATA[*/
		input[type=text], input[type=password] {
			background: #f4f4f4;
			border: 1px solid #ccc;
			border-radius: .2em;
			-moz-border-radius: .2em;
			-webkit-border-radius: .2em;
			margin: .2em;
		}
		input[type=text]:focus, input[type=password]:focus {
			background: #fff;
		}
		select {
			background: #eee;
			border: 1px solid #ccc;
			border-radius: .2em;
			-moz-border-radius: .2em;
			-webkit-border-radius: .2em;
			cursor: pointer;
		}
		input[type=submit] {
			background: url("button.png") bottom left repeat-x #ddd;
			border: 1px solid #ccc;
			border-radius: .2em;
			-moz-border-radius: .2em;
			-webkit-border-radius: .2em;
			cursor: pointer;
			margin: .2em;
		}
		input[type=submit]:hover {
			background: url("button.png") top left repeat-x #eee;
		}
		/*]]>*/
		</style>
		<script type="text/javascript">
		/*<![CDATA[*/
		function loading() {
			document.getElementById('loading').style.display = 'block';
			i = 150;
			direction = 'plus';
			window.setInterval("pulsate()", 20);
			return false;
		}
		function pulsate() {
			if (direction == 'plus') {
				++i;
			} else if (direction == 'minus') {
				--i;
			}
			if (i == 240) {
				direction = 'minus';
			} else if (i == 150) {
				direction = 'plus';
			}
			//window.status = 'rgb('+i+', '+i+', '+i+')';
			document.getElementById('loading').getElementsByTagName('span')[0].style.color = 'rgb('+i+', '+i+', '+i+')';
		}
		/*]]>*/
		</script>
	</head>
	<body>

		<form action="index.php" method="get" style="position: absolute; top: 0px; right: 0px; padding: .2em">
			<select name="locale" size="1" onchange="document.forms[0].submit()">
				<?php
				if ($handle = opendir('./locales')) {
					while (false !== ($file = readdir($handle))) {
						if(is_file('./locales/'.$file.'/info.php')) {
							include('./locales/'.$file.'/info.php');
							if ($file == $langcode) {
								echo '<option value="'.$file.'" selected="selected">'.$locale_info["name"].'</option>';
							} else {
								echo '<option value="'.$file.'">'.$locale_info["name"].'</option>';
							}
						}
					}
					closedir($handle);
				}
				?>
			</select>
			<input type="submit" value="OK" />
		</form>

		<div id="horizon">
			<div id="left">
				<h1>cms -db</h1>
				<?php if ($pleaselogin == true) { locale('text_pleaselogin'); } ?>
				<p>&nbsp;</p>
				<p><?php echo $message; ?></p>
			</div>
			<div id="right">
				<form action="login.php" method="post" onsubmit="loading()">
					<input type="hidden" name="locale" value="<?php echo $langcode ?>" />
					<input type="text" name="user" id="user" value="" /> <label for="user"><?php locale('label_username') ?></label><br />
					<input type="password" name="pass" id="pass" value="" /> <label for="pass"><?php locale('label_password') ?></label><br />
					<input type="submit" value="<?php locale('button_login') ?>" /><br />
				</form>
			</div>
		</div>
		
		<?php
		$version = trim(file_get_contents('./update/version.txt'));
		if (file_exists('../data/version.txt')) {
			$version_installed = trim(file_get_contents('../data/version.txt'));
			if ($version != $version_installed) {
				$version = $version.' [ ! '.$version_installed.' ]';
			}
		}
		?>
		<div id="version">
			<a href="version.php" style="font-size: .8em; color: #99aec2; text-decoration: none"><?php echo $version ?></a>
		</div>
		
		<div id="loading">
			<span>loading...</span>
			<div>cms -db</div>
		</div>

	</body>
</html>
